From: Li Zefan <lizefan@huawei.com>
Subject: memcg: fix build error if CONFIG_MEMCG_KMEM=n

Fix this build error:

mm/built-in.o: In function `mem_cgroup_css_free':
memcontrol.c:(.text+0x5caa6): undefined reference to 'mem_cgroup_sockets_destroy'

Maybe it's better to add memcg_destroy_kmem(), to pair with memcg_init_kmem().

This patch can be folded into "memcg: use css_get/put when charging/uncharging kmem".

Rename the patch as it is a follow-up for the mmotm tree:
"memcg-use-css_get-put-when-charging-uncharging-kmem-fix-fix.patch"

See [1] for the original patch and follow the discussion in [2].

[1] http://marc.info/?l=linux-mm&m=137285590123430&w=2
[2] http://marc.info/?t=137285378500005&r=1&w=2

Reported-by: Fengguang Wu <fengguang.wu@intel.com>
Reported-by: Stephen Rothwell <sfr@canb.auug.org.au>
Reported-by: Sedat Dilek <sedat.dilek@gmail.com>
Tested-by: Sedat Dilek <sedat.dilek@gmail.com>
Acked-by: Michal Hocko <mhocko@suse.cz>
Signed-off-by: Li Zefan <lizefan@huawei.com>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---
[ dileks: v2:
  * Correct last hunk as mem_cgroup_put() exists no more
  * Rename patch-name s/-fix-2/-fix-fix ]

 mm/memcontrol.c |   12 ++++++++++--
 1 file changed, 10 insertions(+), 2 deletions(-)

diff -puN mm/memcontrol.c~memcg-use-css_get-put-when-charging-uncharging-kmem-fix-fix mm/memcontrol.c
--- a/mm/memcontrol.c~memcg-use-css_get-put-when-charging-uncharging-kmem-fix-fix
+++ a/mm/memcontrol.c
@@ -5916,6 +5916,11 @@ static int memcg_init_kmem(struct mem_cg
 	return mem_cgroup_sockets_init(memcg, ss);
 }
 
+static void memcg_destroy_kmem(struct mem_cgroup *memcg)
+{
+	mem_cgroup_sockets_destroy(memcg);
+}
+
 static void kmem_cgroup_css_offline(struct mem_cgroup *memcg)
 {
 	if (!memcg_kmem_is_active(memcg))
@@ -5955,6 +5960,10 @@ static int memcg_init_kmem(struct mem_cg
 	return 0;
 }
 
+static void memcg_destroy_kmem(struct mem_cgroup *memcg)
+{
+}
+
 static void kmem_cgroup_css_offline(struct mem_cgroup *memcg)
 {
 }
@@ -6399,8 +6408,7 @@ static void mem_cgroup_css_free(struct c
 {
 	struct mem_cgroup *memcg = mem_cgroup_from_cont(cont);
 
-	mem_cgroup_sockets_destroy(memcg);
-
+	memcg_destroy_kmem(memcg);
 	__mem_cgroup_free(memcg);
 }
 
_
